/*
    Copyright (C) 2018  Victorien Elvinger

    This Source Code Form is subject to the terms of the Mozilla Public
    License, v. 2.0. If a copy of the MPL was not distributed with this
    file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
/**
 * An anchor can be used to model the cursor, the selection of a participant in
 * a coeditable list.
 *
 * An anchor is always just before a given {@link Pos }.
 */
var Anchor = /** @class */ (function () {
    /**
     * @example
     * Anchor(p) is just before p
     * There not exists another position between Anchor(p) and p
     *
     * @param ref position to which this anchor is relative to
     */
    function Anchor(ref) {
        this.ref = ref;
    }
    /**
     * @param other
     * @return this [Order relation] other
     */
    Anchor.prototype.compare = function (other) {
        return this.ref.compare(other.ref);
    };
    /**
     * @example
     * Anchor(p).compareTo(q) == Ordering.Before if p <= q
     *
     * @param pos
     * @return Is before or after {@link pos}?
     */
    Anchor.prototype.compareTo = function (pos) {
        // TODO: avoid union type.
        // use a specific enum type? or just Ordering?
        var rel = this.ref.compare(pos);
        if (rel !== 0 /* EQUAL */) {
            return rel;
        }
        else {
            return -1 /* BEFORE */;
        }
    };
    return Anchor;
}());
export { Anchor };
//# sourceMappingURL=anchor.js.map