import { Pos } from "./pos";
import { Ordering } from "../util/ordering";
/**
 * An anchor can be used to model the cursor, the selection of a participant in
 * a coeditable list.
 *
 * An anchor is always just before a given {@link Pos }.
 */
export declare class Anchor<P extends Pos<P>> {
    /**
     * Position to which this anchor is relative to
     */
    readonly ref: P;
    /**
     * @example
     * Anchor(p) is just before p
     * There not exists another position between Anchor(p) and p
     *
     * @param ref position to which this anchor is relative to
     */
    constructor(ref: P);
    /**
     * @param other
     * @return this [Order relation] other
     */
    compare(other: Anchor<P>): Ordering;
    /**
     * @example
     * Anchor(p).compareTo(q) == Ordering.Before if p <= q
     *
     * @param pos
     * @return Is before or after {@link pos}?
     */
    compareTo(pos: P): Ordering.BEFORE | Ordering.AFTER;
}
